@@ -1,4 +1,4 @@
-from .explorer import BlockchainExplorer
+from .explorer import BlockchainExplorer, Etherscan, Arbiscan
 from .modules.accounts import Accounts as accounts
 from .modules.blocks import Blocks as blocks
 from .modules.contracts import Contracts as contracts
